==> ktp-desktop-applets-0.7.80.tar.bz2: ktp-desktop-applets-0.7.80/contactlist/org.kde.ktp-contactlist/metadata.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Contact List
Name[bs]=Lista za instant poruke
Name[ca]=Llista de contactes de missatgeria instantània
Name[ca@valencia]=Llista de contactes de missatgeria instantània
Name[cs]=Seznam kontaktů komunikátoru
Name[da]=Instant messaging-kontaktliste
Name[de]=Instant-Messaging-Kontaktliste 
Name[el]=Λίστα επαφών με στιγμιαίο μήνυμα
Name[es]=Lista de contactos de mensajería instantánea
Name[et]=Kiirsuhtluskontaktide nimekiri
Name[fi]=Pikaviestinnän yhteystietoluettelo
Name[fr]=Liste des contacts de messagerie instantanée
Name[ga]=Liosta Teagmhálacha TM
Name[gl]=Lista de contactos da mensaxería instantánea
Name[hu]=Azonnali üzenetküldési partnerlista
Name[ia]=Lista de contacto de messageria instantanee
Name[it]=Lista dei contatti di messaggistica istantanea
Name[kk]=Лезде хабарласу контакт тізімі
Name[lt]=Kontaktų sąrašas
Name[mr]=त्वरित संदेश संपर्क यादी
Name[nb]=Liste over lynmeldingskontakter
Name[nl]=Lijst met contactpersoon van Instant Messaging
Name[pl]=Lista kontaktów komunikatora internetowego
Name[pt]=Lista de Contactos das Mensagens Instantâneas
Name[pt_BR]=Lista de contatos de mensagens instantâneas
Name[ro]=Listă de contacte pentru mesageria instantanee
Name[ru]=Список контактов
Name[sk]=Zoznam kontaktov instant messagingu
Name[sl]=Seznam stikov hipnega sporočanja
Name[sr]=Листа брзогласничких контаката
Name[sr@ijekavian]=Листа брзогласничких контаката
Name[sr@ijekavianlatin]=Lista brzoglasničkih kontakata
Name[sr@latin]=Lista brzoglasničkih kontakata
Name[sv]=Lista över direktmeddelandekontakter
Name[tr]=Anında Mesajlaşma Kişi Listesi
Name[uk]=Список контактів миттєвого обміну повідомленнями
Name[wa]=Djivêye des soçons del messaedjreye sol moumint
Name[x-test]=xxInstant Messaging Contact Listxx
Name[zh_CN]=即时通讯联系人列表
Name[zh_TW]=即時通訊聯絡人清單
Comment=List instant messaging contacts
Comment[bs]=Lista za instant poruke
Comment[ca]=Llista els contactes de missatgeria instantània
Comment[ca@valencia]=Llista els contactes de missatgeria instantània
Comment[cs]=Vypsat kontakty komunikátoru
Comment[da]=Oplist instant messaging-kontakter
Comment[de]=Instant-Messaging-Kontakt auflisten
Comment[el]=Φτιάχνει λίστα με επαφές στιγμιαίων μηνυμάτων
Comment[es]=Lista de contactos de mensajería instantánea
Comment[et]=Kiirsuhtluskontaktide nimekiri
Comment[fi]=Luettele pikaviestiyhteystiedot
Comment[fr]=Liste les contacts de messagerie instantanée
Comment[ga]=Taispeáin teagmhálacha TM
Comment[gl]=Listar os contacto de mensaxería instantánea
Comment[hu]=Azonnali üzenetküldési partnerek listázása
Comment[ia]=Lista contactos de messageria instantanee
Comment[it]=Elenca i contatti di messaggistica istantanea
Comment[kk]=Лезде хабарласу контакттар тізімі
Comment[lt]=Rikiuoti kontaktus
Comment[mr]=त्वरित संदेश संपर्कांची यादी करा
Comment[nb]=List opp lynmeldingskontakter
Comment[nl]=Lijst met contactpersoon van Instant Messaging
Comment[pl]=Wyszczególnij kontakty komunikatora internetowego
Comment[pt]=Apresenta os contactos das mensagens instantâneas
Comment[pt_BR]=Lista os contatos de mensagens instantâneas
Comment[ro]=Afișează contactele de mesagerie instantanee
Comment[ru]=Контакты сети обмена сообщениями
Comment[sk]=Vypísať kontakty instant messagingu
Comment[sl]=Prikaže seznam stikov hipnega sporočanja
Comment[sr]=Набраја брзогласничке контакте
Comment[sr@ijekavian]=Набраја брзогласничке контакте
Comment[sr@ijekavianlatin]=Nabraja brzoglasničke kontakte
Comment[sr@latin]=Nabraja brzoglasničke kontakte
Comment[sv]=Lista direktmeddelandekontakter
Comment[tr]=Anında mesajlaşma kişilerini listele
Comment[uk]=Показати список контактів миттєвого обміну повідомленнями
Comment[wa]=Mostrer l' djivêye di vos soçons di messaedjreye sol moumint
Comment[x-test]=xxList instant messaging contactsxx
Comment[zh_CN]=显示即时通讯联系人
Comment[zh_TW]=列出即時通訊聯絡人
Type=Service
ServiceTypes=Plasma/Applet
Icon=meeting-attending

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-DefaultSize=200,300

X-KDE-PluginInfo-Name=org.kde.ktp-contactlist
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/

X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet
Type=Service

==> ktp-desktop-applets_0.8.0.orig.tar.bz2: ktp-desktop-applets-0.8.0/contactlist/org.kde.ktp-contactlist/metadata.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Contact List
Name[bs]=Lista za instant poruke
Name[ca]=Llista de contactes de missatgeria instantània
Name[ca@valencia]=Llista de contactes de missatgeria instantània
Name[cs]=Seznam kontaktů komunikátoru
Name[da]=Instant messaging-kontaktliste
Name[de]=Instant-Messaging-Kontaktliste 
Name[el]=Λίστα επαφών με στιγμιαίο μήνυμα
Name[es]=Lista de contactos de mensajería instantánea
Name[et]=Kiirsuhtluskontaktide nimekiri
Name[fi]=Pikaviestinnän yhteystietoluettelo
Name[fr]=Liste des contacts de messagerie instantanée
Name[ga]=Liosta Teagmhálacha TM
Name[gl]=Lista de contactos da mensaxería instantánea
Name[hu]=Azonnali üzenetküldési partnerlista
Name[ia]=Lista de contacto de messageria instantanee
Name[it]=Lista dei contatti di messaggistica istantanea
Name[kk]=Лезде хабарласу контакт тізімі
Name[lt]=Kontaktų sąrašas
Name[mr]=त्वरित संदेश संपर्क यादी
Name[nb]=Liste over lynmeldingskontakter
Name[nl]=Lijst met contactpersoon van Instant Messaging
Name[pa]=ਤੁਰੰਤ ਸੁਨੇਹੇ ਸੰਪਰਕ ਸੂਚੀ
Name[pl]=Lista kontaktów komunikatora internetowego
Name[pt]=Lista de Contactos das Mensagens Instantâneas
Name[pt_BR]=Lista de contatos de mensagens instantâneas
Name[ro]=Listă de contacte pentru mesageria instantanee
Name[ru]=Список контактов
Name[sk]=Zoznam kontaktov instant messagingu
Name[sl]=Seznam stikov hipnega sporočanja
Name[sr]=Листа брзогласничких контаката
Name[sr@ijekavian]=Листа брзогласничких контаката
Name[sr@ijekavianlatin]=Lista brzoglasničkih kontakata
Name[sr@latin]=Lista brzoglasničkih kontakata
Name[sv]=Lista över direktmeddelandekontakter
Name[tr]=Anında Mesajlaşma Kişi Listesi
Name[ug]=مۇڭداشقۇ ئالاقەداش تىزىمى
Name[uk]=Список контактів миттєвого обміну повідомленнями
Name[wa]=Djivêye des soçons del messaedjreye sol moumint
Name[x-test]=xxInstant Messaging Contact Listxx
Name[zh_CN]=即时通讯联系人列表
Name[zh_TW]=即時通訊聯絡人清單
Comment=List instant messaging contacts
Comment[bs]=Lista za instant poruke
Comment[ca]=Llista els contactes de missatgeria instantània
Comment[ca@valencia]=Llista els contactes de missatgeria instantània
Comment[cs]=Vypsat kontakty komunikátoru
Comment[da]=Oplist instant messaging-kontakter
Comment[de]=Instant-Messaging-Kontakt auflisten
Comment[el]=Φτιάχνει λίστα με επαφές στιγμιαίων μηνυμάτων
Comment[es]=Lista de contactos de mensajería instantánea
Comment[et]=Kiirsuhtluskontaktide nimekiri
Comment[fi]=Luettele pikaviestiyhteystiedot
Comment[fr]=Liste les contacts de messagerie instantanée
Comment[ga]=Taispeáin teagmhálacha TM
Comment[gl]=Listar os contacto de mensaxería instantánea
Comment[hu]=Azonnali üzenetküldési partnerek listázása
Comment[ia]=Lista contactos de messageria instantanee
Comment[it]=Elenca i contatti di messaggistica istantanea
Comment[kk]=Лезде хабарласу контакттар тізімі
Comment[lt]=Rikiuoti kontaktus
Comment[mr]=त्वरित संदेश संपर्कांची यादी करा
Comment[nb]=List opp lynmeldingskontakter
Comment[nl]=Lijst met contactpersoon van Instant Messaging
Comment[pa]=ਤੁਰੰਤ ਸੁਨੇਹੇ ਸੰਪਰਕ ਸੂਚੀ
Comment[pl]=Wyszczególnij kontakty komunikatora internetowego
Comment[pt]=Apresenta os contactos das mensagens instantâneas
Comment[pt_BR]=Lista os contatos de mensagens instantâneas
Comment[ro]=Afișează contactele de mesagerie instantanee
Comment[ru]=Контакты сети обмена сообщениями
Comment[sk]=Vypísať kontakty instant messagingu
Comment[sl]=Prikaže seznam stikov hipnega sporočanja
Comment[sr]=Набраја брзогласничке контакте
Comment[sr@ijekavian]=Набраја брзогласничке контакте
Comment[sr@ijekavianlatin]=Nabraja brzoglasničke kontakte
Comment[sr@latin]=Nabraja brzoglasničke kontakte
Comment[sv]=Lista direktmeddelandekontakter
Comment[tr]=Anında mesajlaşma kişilerini listele
Comment[uk]=Показати список контактів миттєвого обміну повідомленнями
Comment[wa]=Mostrer l' djivêye di vos soçons di messaedjreye sol moumint
Comment[x-test]=xxList instant messaging contactsxx
Comment[zh_CN]=显示即时通讯联系人
Comment[zh_TW]=列出即時通訊聯絡人
Type=Service
ServiceTypes=Plasma/Applet
Icon=meeting-attending

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-DefaultSize=200,300

X-KDE-PluginInfo-Name=org.kde.ktp-contactlist
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=David Edmundson
X-KDE-PluginInfo-Email=kde@davidedmundson.co.uk
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/

X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet
Type=Service
